faer::mat

Trait AsMatMut

pub trait AsMatMut<E: Entity>: AsMatRef<E> {
    // Required method
    fn as_mat_mut(&mut self) -> MatMut<'_, E, Self::R, Self::C>;
}
Trait for types that can be converted to a mutable matrix view.

This trait is implemented for types of the matrix family, like Mat, MatRef, and MatMut, but not for types like Col, Row, or their families. For a more general trait, see As2D.

Required Methods

fn as_mat_mut(&mut self) -> MatMut<'_, E, Self::R, Self::C>

Convert to a mutable matrix view.

Implementations on Foreign Types

Source

impl<E: Entity, T: AsMatMut<E>> AsMatMut<E> for &mut T

Source

fn as_mat_mut(&mut self) -> MatMut<'_, E, Self::R, Self::C>

Implementors

Source

impl<E: Entity, R: Shape, C: Shape> AsMatMut<E> for Mat<E, R, C>

Source

impl<E: Entity, R: Shape, C: Shape> AsMatMut<E> for MatMut<'_, E, R, C>