pub trait MatIndex<RowRange, ColRange> {
type Target;
// Required methods
fn get(this: Self, row: RowRange, col: ColRange) -> Self::Target;
unsafe fn get_unchecked(
this: Self,
row: RowRange,
col: ColRange,
) -> Self::Target;
}Expand description
represents a type that can be used to slice a matrix, such as an index or a range of indices
Required Associated Types
Required Methods
Sourceunsafe fn get_unchecked(
this: Self,
row: RowRange,
col: ColRange,
) -> Self::Target
unsafe fn get_unchecked( this: Self, row: RowRange, col: ColRange, ) -> Self::Target
slice this using row and col without bound checks
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".