faer::sparse

Struct SymbolicSparseRowMat

pub struct SymbolicSparseRowMat<I: Index, R: Shape = usize, C: Shape = usize> { /* private fields */ }
Symbolic structure of sparse matrix in row format, either compressed or uncompressed.

Requires:

  • nrows <= I::Signed::MAX (always checked)

  • ncols <= I::Signed::MAX (always checked)

  • row_ptrs has length nrows + 1 (always checked)

  • row_ptrs is increasing

  • row_ptrs[0]..row_ptrs[nrows] is a valid range in row_indices (always checked, assuming increasing)

  • if nnz_per_row is None, elements of col_indices[row_ptrs[i]..row_ptrs[i + 1]] are less than ncols

  • nnz_per_row[i] <= row_ptrs[i+1] - row_ptrs[i]

  • if nnz_per_row is Some(_), elements of col_indices[row_ptrs[i]..][..nnz_per_row[i]] are less than ncols

  • Within each row, column indices are sorted in increasing order.

Note

Some algorithms allow working with matrices containing unsorted row indices per column.

Passing such a matrix to an algorithm that does not explicitly permit this is unspecified (though not undefined) behavior.

Implementations

Source

impl<I: Index, R: Shape, C: Shape> SymbolicSparseRowMat<I, R, C>

pub fn new_checked( nrows: R, ncols: C, row_ptrs: Vec<I>, nnz_per_row: Option<Vec<I>>, col_indices: Vec<I>, ) -> Self

Creates a new symbolic matrix view after asserting its invariants.

Panics

See type level documentation.

pub fn new_unsorted_checked( nrows: R, ncols: C, row_ptrs: Vec<I>, nnz_per_row: Option<Vec<I>>, col_indices: Vec<I>, ) -> Self

Creates a new symbolic matrix view from data containing duplicate and/or unsorted column indices per row, after asserting its other invariants.

Panics

See type level documentation.

pub unsafe fn new_unchecked( nrows: R, ncols: C, row_ptrs: Vec<I>, nnz_per_row: Option<Vec<I>>, col_indices: Vec<I>, ) -> Self

Creates a new symbolic matrix view without asserting its invariants.

Safety

See type level documentation.

pub fn into_parts(self) -> (R, C, Vec<I>, Option<Vec<I>>, Vec<I>)

Returns the components of the matrix in the order:

  • row count,
  • column count,
  • row pointers,
  • nonzeros per row,
  • column indices.
pub fn as_ref(&self) -> SymbolicSparseRowMatRef<'_, I, R, C>

Returns a view over the symbolic structure of self.

pub fn nrows(&self) -> R

Returns the number of rows of the matrix.

pub fn ncols(&self) -> C

Returns the number of columns of the matrix.

pub fn shape(&self) -> (R, C)

Returns the number of rows and columns of the matrix.

pub fn into_transpose(self) -> SymbolicSparseColMat<I, C, R>

Consumes the matrix, and returns its transpose in column-major format without reallocating.

Note

Allows unsorted matrices, producing an unsorted output.

pub fn to_owned(&self) -> Result<SymbolicSparseRowMat<I, R, C>, FaerError>

Copies the current matrix into a newly allocated matrix.

Note

Allows unsorted matrices, producing an unsorted output.

pub fn to_col_major(&self) -> Result<SymbolicSparseColMat<I, R, C>, FaerError>

Copies the current matrix into a newly allocated matrix, with column-major order.

Note

Allows unsorted matrices, producing a sorted output. Duplicate entries are kept, however.

pub fn compute_nnz(&self) -> usize

Returns the number of symbolic non-zeros in the matrix.

The value is guaranteed to be less than I::Signed::MAX.

Note

Allows unsorted matrices, but the output is a count of all the entries, including the duplicate ones.

pub fn row_ptrs(&self) -> &[I]

Returns the column pointers.

pub fn nnz_per_row(&self) -> Option<&[I]>

Returns the count of non-zeros per row of the matrix.

pub fn col_indices(&self) -> &[I]

Returns the column indices.

pub fn col_indices_of_row_raw(&self, i: Idx<R>) -> &[Idx<C, I>]

Returns the column indices of row i.

Panics

Panics if i >= self.nrows().

pub fn col_indices_of_row_raw_unbound(&self, i: Idx<R>) -> &[I]

Returns the column indices of row i.

Panics

Panics if i >= self.nrows().

pub fn col_indices_of_row( &self, i: Idx<R>, ) -> impl '_ + ExactSizeIterator + DoubleEndedIterator<Item = Idx<C>>

Returns the column indices of row i.

Panics

Panics if i >= self.ncols().

pub fn row_range(&self, i: Idx<R>) -> Range<usize>

Returns the range that the row i occupies in self.col_indices().

Panics

Panics if i >= self.nrows().

pub unsafe fn row_range_unchecked(&self, i: Idx<R>) -> Range<usize>

Returns the range that the row i occupies in self.col_indices().

Safety

The behavior is undefined if i >= self.nrows().

pub fn try_new_from_indices( nrows: R, ncols: C, indices: &[(Idx<R, I>, Idx<C, I>)], ) -> Result<(Self, ValuesOrder<I>), CreationError>

Create a new symbolic structure, and the corresponding order for the numerical values from pairs of indices (row, col).

Source

impl<I: Index> SymbolicSparseRowMat<I>

pub fn try_new_from_nonnegative_indices( nrows: usize, ncols: usize, indices: &[(I::Signed, I::Signed)], ) -> Result<(Self, ValuesOrder<I>), CreationError>

Create a new symbolic structure, and the corresponding order for the numerical values from pairs of indices (row, col).

Negative indices are ignored.