Row

Type Alias Row 

pub type Row<T, Cols = usize> = Row<Own<T, Cols>>;
heap allocated resizable row vector.

note

the memory layout of Row is guaranteed to be row-major, meaning that it has a column stride of 1.

Aliased Type

#[repr(transparent)]
pub struct Row<T, Cols = usize>(pub Own<T, Cols>);

Tuple Fields

0: Own<T, Cols>

Implementations

Source

impl<T, Cols: Shape> Row<T, Cols>

pub fn from_fn(ncols: Cols, f: impl FnMut(Idx<Cols>) -> T) -> Self

returns a new row with dimension ncols, filled with the provided function

pub fn zeros(ncols: Cols) -> Self
where T: ComplexField,

returns a new row with dimension ncols, filled with zeros

pub fn ones(ncols: Cols) -> Self
where T: ComplexField,

returns a new row with dimension ncols, filled with ones

pub fn full(ncols: Cols, value: T) -> Self
where T: Clone,

returns a new row with dimension ncols, filled with value

pub fn try_reserve( &mut self, new_row_capacity: usize, ) -> Result<(), TryReserveError>

reserves the minimum capacity for col_capacity columns without reallocating, or returns an error in case of failure. does nothing if the capacity is already sufficient

pub fn reserve(&mut self, new_row_capacity: usize)

reserves the minimum capacity for col_capacity columns without reallocating. does nothing if the capacity is already sufficient

pub fn resize_with(&mut self, new_ncols: Cols, f: impl FnMut(Idx<Cols>) -> T)

resizes the row in-place so that the new dimension is new_ncols. new elements are created with the given function f, so that elements at index j are created by calling f(j)

pub fn truncate(&mut self, new_ncols: Cols)

truncates the row so that its new dimensions are new_ncols.
the new dimension must be smaller than or equal to the current dimension

panics

the function panics if any of the following conditions are violated:

  • new_ncols > self.ncols()
pub fn into_col_shape<V: Shape>(self, ncols: V) -> Row<T, V>

pub fn into_diagonal(self) -> Diag<T, Cols>

pub fn into_transpose(self) -> Col<T, Cols>

Source

impl<T, Cols: Shape> Row<T, Cols>

pub fn nrows(&self) -> usize

returns the number of rows of the row (always 1)

pub fn ncols(&self) -> Cols

returns the number of columns of the row

Source

impl<T, Cols: Shape> Row<T, Cols>

pub fn as_ptr(&self) -> *const T

pub fn shape(&self) -> (usize, Cols)

pub fn col_stride(&self) -> isize

pub fn ptr_at(&self, col: IdxInc<Cols>) -> *const T

pub unsafe fn ptr_inbounds_at(&self, col: Idx<Cols>) -> *const T

pub fn split_at_col( &self, col: IdxInc<Cols>, ) -> (RowRef<'_, T, usize>, RowRef<'_, T, usize>)

pub fn transpose(&self) -> ColRef<'_, T, Cols>

pub fn conjugate(&self) -> RowRef<'_, T::Conj, Cols>
where T: Conjugate,

pub fn canonical(&self) -> RowRef<'_, T::Canonical, Cols>
where T: Conjugate,

pub fn adjoint(&self) -> ColRef<'_, T::Conj, Cols>
where T: Conjugate,

pub fn get<ColRange>( &self, col: ColRange, ) -> <RowRef<'_, T, Cols> as RowIndex<ColRange>>::Target
where for<'a> RowRef<'a, T, Cols>: RowIndex<ColRange>,

pub unsafe fn get_unchecked<ColRange>( &self, col: ColRange, ) -> <RowRef<'_, T, Cols> as RowIndex<ColRange>>::Target
where for<'a> RowRef<'a, T, Cols>: RowIndex<ColRange>,

pub fn reverse_cols(&self) -> RowRef<'_, T, Cols>

pub fn subcols<V: Shape>( &self, col_start: IdxInc<Cols>, ncols: V, ) -> RowRef<'_, T, V>

pub fn as_col_shape<V: Shape>(&self, ncols: V) -> RowRef<'_, T, V>

pub fn as_dyn_cols(&self) -> RowRef<'_, T, usize>

pub fn as_dyn_stride(&self) -> RowRef<'_, T, Cols, isize>

pub fn iter( &self, ) -> impl '_ + ExactSizeIterator + DoubleEndedIterator<Item = &T>

pub fn par_iter(&self) -> impl '_ + IndexedParallelIterator<Item = &T>
where T: Sync,

pub fn try_as_row_major(&self) -> Option<RowRef<'_, T, Cols, ContiguousFwd>>

pub fn as_diagonal(&self) -> DiagRef<'_, T, Cols>

pub unsafe fn const_cast(&self) -> RowMut<'_, T, Cols>

pub fn as_mat(&self) -> MatRef<'_, T, usize, Cols, isize>

pub fn as_mat_mut(&mut self) -> MatMut<'_, T, usize, Cols, isize>

Source

impl<T, Cols: Shape> Row<T, Cols>

pub fn as_ptr_mut(&mut self) -> *mut T

pub fn ptr_at_mut(&mut self, col: IdxInc<Cols>) -> *mut T

pub unsafe fn ptr_inbounds_at_mut(&mut self, col: Idx<Cols>) -> *mut T

pub fn split_at_col_mut( &mut self, col: IdxInc<Cols>, ) -> (RowMut<'_, T, usize>, RowMut<'_, T, usize>)

pub fn transpose_mut(&mut self) -> ColMut<'_, T, Cols>

pub fn conjugate_mut(&mut self) -> RowMut<'_, T::Conj, Cols>
where T: Conjugate,

pub fn canonical_mut(&mut self) -> RowMut<'_, T::Canonical, Cols>
where T: Conjugate,

pub fn adjoint_mut(&mut self) -> ColMut<'_, T::Conj, Cols>
where T: Conjugate,

pub fn get_mut<ColRange>( &mut self, col: ColRange, ) -> <RowMut<'_, T, Cols> as RowIndex<ColRange>>::Target
where for<'a> RowMut<'a, T, Cols>: RowIndex<ColRange>,

pub unsafe fn get_mut_unchecked<ColRange>( &mut self, col: ColRange, ) -> <RowMut<'_, T, Cols> as RowIndex<ColRange>>::Target
where for<'a> RowMut<'a, T, Cols>: RowIndex<ColRange>,

pub fn reverse_cols_mut(&mut self) -> RowMut<'_, T, Cols>

pub fn subcols_mut<V: Shape>( &mut self, col_start: IdxInc<Cols>, ncols: V, ) -> RowMut<'_, T, V>

pub fn as_col_shape_mut<V: Shape>(&mut self, ncols: V) -> RowMut<'_, T, V>

pub fn as_dyn_cols_mut(&mut self) -> RowMut<'_, T, usize>

pub fn as_dyn_stride_mut(&mut self) -> RowMut<'_, T, Cols, isize>

pub fn iter_mut( &mut self, ) -> impl '_ + ExactSizeIterator + DoubleEndedIterator<Item = &mut T>

pub fn par_iter_mut( &mut self, ) -> impl '_ + IndexedParallelIterator<Item = &mut T>
where T: Send,

pub fn try_as_row_major_mut( &mut self, ) -> Option<RowMut<'_, T, Cols, ContiguousFwd>>

pub fn as_diagonal_mut(&mut self) -> DiagMut<'_, T, Cols>

Source

impl<T, Cols: Shape> Row<T, Cols>
where T: RealField,

pub fn max(&self) -> Option<T>

Returns the maximum element in the row, or None if the row is empty

pub fn min(&self) -> Option<T>

Returns the minimum element in the row, or None if the row is empty