faer::sparse

Struct SparseColMatRef

pub struct SparseColMatRef<'a, I: Index, E: Entity, R: Shape = usize, C: Shape = usize> { /* private fields */ }
Sparse matrix view in column-major format, either compressed or uncompressed.

Implementations

Source

impl<'a, I: Index, E: Entity, R: Shape, C: Shape> SparseColMatRef<'a, I, E, R, C>

pub fn new( symbolic: SymbolicSparseColMatRef<'a, I, R, C>, values: Slice<'a, E>, ) -> Self

Creates a new sparse matrix view.

Panics

Panics if the length of values is not equal to the length of symbolic.row_indices().

pub fn nrows(&self) -> R

Returns the number of rows of the matrix.

pub fn ncols(&self) -> C

Returns the number of columns of the matrix.

pub fn shape(&self) -> (R, C)

Returns the number of rows and columns of the matrix.

pub fn as_ref(&self) -> SparseColMatRef<'_, I, E, R, C>

Returns a view over self.

pub fn to_owned(&self) -> Result<SparseColMat<I, E::Canonical, R, C>, FaerError>
where E: Conjugate<Canonical: ComplexField>,

Copies self into a newly allocated matrix.

Note

Allows unsorted matrices, producing an unsorted output.

pub fn to_sorted( &self, ) -> Result<SparseColMat<I, E::Canonical, R, C>, FaerError>

Copies self into a newly allocated matrix with sorted indices.

Note

Allows unsorted matrices, producing a sorted output.

pub fn to_dense(&self) -> Mat<E::Canonical, R, C>
where E: Conjugate<Canonical: ComplexField>,

Copies self into a newly allocated dense matrix

pub fn to_row_major( &self, ) -> Result<SparseRowMat<I, E::Canonical, R, C>, FaerError>

Copies self into a newly allocated matrix, with row-major order.

Note

Allows unsorted matrices, producing a sorted output.

pub fn transpose(self) -> SparseRowMatRef<'a, I, E, C, R>

Returns a view over the transpose of self in row-major format.

pub fn conjugate(self) -> SparseColMatRef<'a, I, E::Conj, R, C>
where E: Conjugate,

Returns a view over the conjugate of self.

pub fn canonicalize(self) -> (SparseColMatRef<'a, I, E::Canonical, R, C>, Conj)
where E: Conjugate,

Returns a view over the canonical view of self, along with whether it has been conjugated or not.

pub fn adjoint(self) -> SparseRowMatRef<'a, I, E::Conj, C, R>
where E: Conjugate,

Returns a view over the conjugate transpose of self.

pub fn values(self) -> Slice<'a, E>

Returns the numerical values of the matrix.

pub fn values_of_col(self, j: Idx<C>) -> Slice<'a, E>

Returns the numerical values of column j of the matrix.

Panics:

Panics if j >= ncols.

pub fn symbolic(&self) -> SymbolicSparseColMatRef<'a, I, R, C>

Returns the symbolic structure of the matrix.

pub fn parts(self) -> (SymbolicSparseColMatRef<'a, I, R, C>, Slice<'a, E>)

Decomposes the matrix into the symbolic part and the numerical values.

pub fn compute_nnz(&self) -> usize

Returns the number of symbolic non-zeros in the matrix.

The value is guaranteed to be less than I::Signed::MAX.

Note

Allows unsorted matrices, but the output is a count of all the entries, including the duplicate ones.

pub fn col_ptrs(&self) -> &'a [I]

Returns the column pointers.

pub fn nnz_per_col(&self) -> Option<&'a [I]>

Returns the count of non-zeros per column of the matrix.

pub fn row_indices(&self) -> &'a [I]

Returns the row indices.

pub fn row_indices_of_col_raw(&self, j: Idx<C>) -> &'a [Idx<R, I>]

Returns the row indices of column j.

Panics

Panics if j >= self.ncols().

pub fn row_indices_of_col( &self, j: Idx<C>, ) -> impl 'a + ExactSizeIterator + DoubleEndedIterator<Item = Idx<R>>

Returns the row indices of column j.

Panics

Panics if j >= self.ncols().

pub fn col_range(&self, j: Idx<C>) -> Range<usize>

Returns the range that the column j occupies in self.row_indices().

Panics

Panics if j >= self.ncols().

pub unsafe fn col_range_unchecked(&self, j: Idx<C>) -> Range<usize>

Returns the range that the column j occupies in self.row_indices().

Safety

The behavior is undefined if j >= self.ncols().

pub fn get(self, row: Idx<R>, col: Idx<C>) -> Option<Ref<'a, E>>

Returns a reference to the value at the given index, or None if the symbolic structure doesn’t contain it, or contains multiple indices with the given index.

Panics

Panics if row >= self.nrows().
Panics if col >= self.ncols().

pub fn get_all(self, row: Idx<R>, col: Idx<C>) -> Slice<'a, E>

Returns a reference to a slice containing the values at the given index using a binary search.

Panics

Panics if row >= self.nrows().
Panics if col >= self.ncols().

pub fn as_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SparseColMatRef<'a, I, E, V, H>

Returns the input matrix with the given shape after checking that it matches the current shape.

pub fn as_dyn(self) -> SparseColMatRef<'a, I, E>

Returns the input matrix with dynamic shape.

Source

impl<I: Index, E: ComplexField> SparseColMatRef<'_, I, E>

pub fn sp_solve_lower_triangular_in_place(&self, rhs: impl ColBatchMut<E>)

Assuming self is a lower triangular matrix, solves the equation self * X = rhs, and stores the result in rhs.

Note

The matrix indices need not be sorted, but the diagonal element is assumed to be the first stored element in each column.

pub fn sp_solve_upper_triangular_in_place(&self, rhs: impl ColBatchMut<E>)

Assuming self is an upper triangular matrix, solves the equation self * X = rhs, and stores the result in rhs.

Note

The matrix indices need not be sorted, but the diagonal element is assumed to be the last stored element in each column.

pub fn sp_solve_unit_lower_triangular_in_place(&self, rhs: impl ColBatchMut<E>)

Assuming self is a unit lower triangular matrix, solves the equation self * X = rhs, and stores the result in rhs.

Note

The matrix indices need not be sorted, but the diagonal element is assumed to be the first stored element in each column.

pub fn sp_solve_unit_upper_triangular_in_place(&self, rhs: impl ColBatchMut<E>)

Assuming self is a unit upper triangular matrix, solves the equation self * X = rhs, and stores the result in rhs.

Note

The matrix indices need not be sorted, but the diagonal element is assumed to be the last stored element in each column.

pub fn sp_cholesky(&self, side: Side) -> Result<Cholesky<I, E>, CholeskyError>

Returns the Cholesky decomposition of self. Only the provided side is accessed.

pub fn sp_lu(&self) -> Result<Lu<I, E>, LuError>

Returns the LU decomposition of self with partial (row) pivoting.

pub fn sp_qr(&self) -> Result<Qr<I, E>, FaerError>

Returns the QR decomposition of self.