pub struct SparseColMatRef<'a, I: Index, E: Entity, R: Shape = usize, C: Shape = usize> { /* private fields */ }Expand description
Sparse matrix view in column-major format, either compressed or uncompressed.
Implementations
Sourceimpl<'a, I: Index, E: Entity, R: Shape, C: Shape> SparseColMatRef<'a, I, E, R, C>
impl<'a, I: Index, E: Entity, R: Shape, C: Shape> SparseColMatRef<'a, I, E, R, C>
Sourcepub fn new(
symbolic: SymbolicSparseColMatRef<'a, I, R, C>,
values: Slice<'a, E>,
) -> Self
pub fn new( symbolic: SymbolicSparseColMatRef<'a, I, R, C>, values: Slice<'a, E>, ) -> Self
Creates a new sparse matrix view.
Panics
Panics if the length of values is not equal to the length of
symbolic.row_indices().
Sourcepub fn as_ref(&self) -> SparseColMatRef<'_, I, E, R, C>
pub fn as_ref(&self) -> SparseColMatRef<'_, I, E, R, C>
Returns a view over self.
Sourcepub fn to_owned(&self) -> Result<SparseColMat<I, E::Canonical, R, C>, FaerError>where
E: Conjugate<Canonical: ComplexField>,
pub fn to_owned(&self) -> Result<SparseColMat<I, E::Canonical, R, C>, FaerError>where
E: Conjugate<Canonical: ComplexField>,
Copies self into a newly allocated matrix.
Note
Allows unsorted matrices, producing an unsorted output.
Sourcepub fn to_sorted(
&self,
) -> Result<SparseColMat<I, E::Canonical, R, C>, FaerError>
pub fn to_sorted( &self, ) -> Result<SparseColMat<I, E::Canonical, R, C>, FaerError>
Copies self into a newly allocated matrix with sorted indices.
Note
Allows unsorted matrices, producing a sorted output.
Sourcepub fn to_dense(&self) -> Mat<E::Canonical, R, C>where
E: Conjugate<Canonical: ComplexField>,
pub fn to_dense(&self) -> Mat<E::Canonical, R, C>where
E: Conjugate<Canonical: ComplexField>,
Copies self into a newly allocated dense matrix
Sourcepub fn to_row_major(
&self,
) -> Result<SparseRowMat<I, E::Canonical, R, C>, FaerError>
pub fn to_row_major( &self, ) -> Result<SparseRowMat<I, E::Canonical, R, C>, FaerError>
Copies self into a newly allocated matrix, with row-major order.
Note
Allows unsorted matrices, producing a sorted output.
Sourcepub fn transpose(self) -> SparseRowMatRef<'a, I, E, C, R>
pub fn transpose(self) -> SparseRowMatRef<'a, I, E, C, R>
Returns a view over the transpose of self in row-major format.
Sourcepub fn conjugate(self) -> SparseColMatRef<'a, I, E::Conj, R, C>where
E: Conjugate,
pub fn conjugate(self) -> SparseColMatRef<'a, I, E::Conj, R, C>where
E: Conjugate,
Returns a view over the conjugate of self.
Sourcepub fn canonicalize(self) -> (SparseColMatRef<'a, I, E::Canonical, R, C>, Conj)where
E: Conjugate,
pub fn canonicalize(self) -> (SparseColMatRef<'a, I, E::Canonical, R, C>, Conj)where
E: Conjugate,
Returns a view over the canonical view of self, along with whether it has been conjugated
or not.
Sourcepub fn adjoint(self) -> SparseRowMatRef<'a, I, E::Conj, C, R>where
E: Conjugate,
pub fn adjoint(self) -> SparseRowMatRef<'a, I, E::Conj, C, R>where
E: Conjugate,
Returns a view over the conjugate transpose of self.
Sourcepub fn values_of_col(self, j: Idx<C>) -> Slice<'a, E>
pub fn values_of_col(self, j: Idx<C>) -> Slice<'a, E>
Sourcepub fn symbolic(&self) -> SymbolicSparseColMatRef<'a, I, R, C>
pub fn symbolic(&self) -> SymbolicSparseColMatRef<'a, I, R, C>
Returns the symbolic structure of the matrix.
Sourcepub fn parts(self) -> (SymbolicSparseColMatRef<'a, I, R, C>, Slice<'a, E>)
pub fn parts(self) -> (SymbolicSparseColMatRef<'a, I, R, C>, Slice<'a, E>)
Decomposes the matrix into the symbolic part and the numerical values.
Sourcepub fn compute_nnz(&self) -> usize
pub fn compute_nnz(&self) -> usize
Returns the number of symbolic non-zeros in the matrix.
The value is guaranteed to be less than I::Signed::MAX.
Note
Allows unsorted matrices, but the output is a count of all the entries, including the duplicate ones.
Sourcepub fn nnz_per_col(&self) -> Option<&'a [I]>
pub fn nnz_per_col(&self) -> Option<&'a [I]>
Returns the count of non-zeros per column of the matrix.
Sourcepub fn row_indices(&self) -> &'a [I]
pub fn row_indices(&self) -> &'a [I]
Returns the row indices.
Sourcepub fn row_indices_of_col_raw(&self, j: Idx<C>) -> &'a [Idx<R, I>]
pub fn row_indices_of_col_raw(&self, j: Idx<C>) -> &'a [Idx<R, I>]
Sourcepub fn row_indices_of_col(
&self,
j: Idx<C>,
) -> impl 'a + ExactSizeIterator + DoubleEndedIterator<Item = Idx<R>>
pub fn row_indices_of_col( &self, j: Idx<C>, ) -> impl 'a + ExactSizeIterator + DoubleEndedIterator<Item = Idx<R>>
Sourcepub fn col_range(&self, j: Idx<C>) -> Range<usize> ⓘ
pub fn col_range(&self, j: Idx<C>) -> Range<usize> ⓘ
Returns the range that the column j occupies in self.row_indices().
Panics
Panics if j >= self.ncols().
Sourcepub unsafe fn col_range_unchecked(&self, j: Idx<C>) -> Range<usize> ⓘ
pub unsafe fn col_range_unchecked(&self, j: Idx<C>) -> Range<usize> ⓘ
Returns the range that the column j occupies in self.row_indices().
Safety
The behavior is undefined if j >= self.ncols().
Sourcepub fn get(self, row: Idx<R>, col: Idx<C>) -> Option<Ref<'a, E>>
pub fn get(self, row: Idx<R>, col: Idx<C>) -> Option<Ref<'a, E>>
Returns a reference to the value at the given index, or None if the symbolic structure doesn’t contain it, or contains multiple indices with the given index.
Panics
Panics if row >= self.nrows().
Panics if col >= self.ncols().
Sourcepub fn get_all(self, row: Idx<R>, col: Idx<C>) -> Slice<'a, E>
pub fn get_all(self, row: Idx<R>, col: Idx<C>) -> Slice<'a, E>
Returns a reference to a slice containing the values at the given index using a binary search.
Panics
Panics if row >= self.nrows().
Panics if col >= self.ncols().
Sourcepub fn as_shape<V: Shape, H: Shape>(
self,
nrows: V,
ncols: H,
) -> SparseColMatRef<'a, I, E, V, H>
pub fn as_shape<V: Shape, H: Shape>( self, nrows: V, ncols: H, ) -> SparseColMatRef<'a, I, E, V, H>
Returns the input matrix with the given shape after checking that it matches the current shape.
Sourcepub fn as_dyn(self) -> SparseColMatRef<'a, I, E>
pub fn as_dyn(self) -> SparseColMatRef<'a, I, E>
Returns the input matrix with dynamic shape.
Sourceimpl<I: Index, E: ComplexField> SparseColMatRef<'_, I, E>
impl<I: Index, E: ComplexField> SparseColMatRef<'_, I, E>
Sourcepub fn sp_solve_lower_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
pub fn sp_solve_lower_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
Assuming self is a lower triangular matrix, solves the equation self * X = rhs, and
stores the result in rhs.
Note
The matrix indices need not be sorted, but the diagonal element is assumed to be the first stored element in each column.
Sourcepub fn sp_solve_upper_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
pub fn sp_solve_upper_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
Assuming self is an upper triangular matrix, solves the equation self * X = rhs, and
stores the result in rhs.
Note
The matrix indices need not be sorted, but the diagonal element is assumed to be the last stored element in each column.
Sourcepub fn sp_solve_unit_lower_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
pub fn sp_solve_unit_lower_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
Assuming self is a unit lower triangular matrix, solves the equation self * X = rhs,
and stores the result in rhs.
Note
The matrix indices need not be sorted, but the diagonal element is assumed to be the first stored element in each column.
Sourcepub fn sp_solve_unit_upper_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
pub fn sp_solve_unit_upper_triangular_in_place(&self, rhs: impl ColBatchMut<E>)
Assuming self is a unit upper triangular matrix, solves the equation self * X = rhs,
and stores the result in rhs.
Note
The matrix indices need not be sorted, but the diagonal element is assumed to be the last stored element in each column.
Sourcepub fn sp_cholesky(&self, side: Side) -> Result<Cholesky<I, E>, CholeskyError>
pub fn sp_cholesky(&self, side: Side) -> Result<Cholesky<I, E>, CholeskyError>
Returns the Cholesky decomposition of self. Only the provided side is accessed.